==> pyCOMPS-2.3.6-py2.py3-none-any.whl: COMPS/Data/TaggableEntity.py <==
from enum import Enum
import logging
from COMPS import Client
from COMPS.Data.BaseEntity import get_entity_type
# from COMPS.Data.Simulation import SimulationState

logger = logging.getLogger('COMPS.Data.TaggableEntity')

class TaggableEntity(object):

    def set_tags(self, tags):
        """
        Set the tag key/value pairs associated with this entity.

        If the entity has any existing tags, they will be replaced by the tags specified.  If this is a new entity,
        tags will not be updated until the entity is saved, otherwise tags are updated immediately.

        :param tags: A dictionary containing the key/value tag-string pairs to set.
        """
        if not self._id:
            self._tags = tags   # JPS : should we create a copy here?  If someone uses the same underlying object, could they change it before we save?
            self._register_change()
            return

        self._save_tags(tags, TagOperationMode.Replace)

    def merge_tags(self, tags):
        """
        Merge the given tag key/value pairs with existing tags for this entity.

        Any tag keys that already have an existing tag with that key specified for the entity will have
        their values replaced by the value specified.  Any tag keys that don't already exist for the entity
        will be added with their specified value.

        :param tags: A dictionary containing the key/value tag-string pairs to merge.
        """
        self._save_tags(tags, TagOperationMode.Merge)

    def delete_tags(self, tags):
        """
        Delete the given tag keys for this entity.

        :param tags: A dictionary containing the key tag-strings to delete (Note: values are ignored).
        """
        self._save_tags(tags, TagOperationMode.Delete)

    def _save_tags(self, tags, tag_op_mode):
        et = get_entity_type(self.__class__)

        if not self._id:
            raise RuntimeError('Can\'t {0} tags on {1} {2} that hasn\'t been saved!'.format(tag_op_mode.name.lower(),
                                                                                            et.article,
                                                                                            et.name))

        path = '/{0}s/{1}/Tags'.format(et.name, str(self._id))
        resp = Client.post(path,
                           json={'Tags': tags, 'OperationMode': tag_op_mode.name})


class TagOperationMode(Enum):
    Merge = 1
    Replace = 2
    Delete = 3

==> pyCOMPS-2.6.0-py2.py3-none-any.whl: COMPS/Data/TaggableEntity.py <==
from enum import Enum
import logging
from COMPS import Client
from COMPS.Data.BaseEntity import get_entity_type
# from COMPS.Data.Simulation import SimulationState

logger = logging.getLogger(__name__)

class TaggableEntity(object):

    def set_tags(self, tags):
        """
        Set the tag key/value pairs associated with this entity.

        If the entity has any existing tags, they will be replaced by the tags specified.  If this is a new entity,
        tags will not be updated until the entity is saved, otherwise tags are updated immediately.

        :param tags: A dictionary containing the key/value tag-string pairs to set.
        """
        if not self._id:
            self._tags = tags   # JPS : should we create a copy here?  If someone uses the same underlying object, could they change it before we save?
            self._register_change()
            return

        self._save_tags(tags, TagOperationMode.Replace)

    def merge_tags(self, tags):
        """
        Merge the given tag key/value pairs with existing tags for this entity.

        Any tag keys that already have an existing tag with that key specified for the entity will have
        their values replaced by the value specified.  Any tag keys that don't already exist for the entity
        will be added with their specified value.

        :param tags: A dictionary containing the key/value tag-string pairs to merge.
        """
        self._save_tags(tags, TagOperationMode.Merge)

    def delete_tags(self, tags):
        """
        Delete the given tag keys for this entity.

        :param tags: A dictionary containing the key tag-strings to delete (Note: values are ignored).
        """
        self._save_tags(tags, TagOperationMode.Delete)

    def _save_tags(self, tags, tag_op_mode):
        et = get_entity_type(self.__class__)

        if not self._id:
            raise RuntimeError('Can\'t {0} tags on {1} {2} that hasn\'t been saved!'.format(tag_op_mode.name.lower(),
                                                                                            et.article,
                                                                                            et.name))

        path = '/{0}s/{1}/Tags'.format(et.name, str(self._id))
        resp = Client.post(path,
                           json={'Tags': tags, 'OperationMode': tag_op_mode.name})


class TagOperationMode(Enum):
    Merge = 1
    Replace = 2
    Delete = 3
